class.docx4r.DataTable = "org/lysis/reporters/docx4r/elements/DataTable"
class.docx4r.POT = "org/lysis/reporters/docx4r/elements/POT"
class.fontMetric = "org/lysis/reporters/graphicaldevices/fonts/FontMetric"
class.fontInfo = "org/lysis/reporters/graphicaldevices/fonts/FontInfo"
class.html4r.DataTable = "org/lysis/reporters/html4r/elements/DataTable"
class.html4r.POT = "org/lysis/reporters/html4r/elements/POT"
class.html4r.ImagesList = "org/lysis/reporters/html4r/elements/ImagesList"
class.html4r.POTsList = "org/lysis/reporters/html4r/elements/SetOfPot"
class.html4r.RAPHAELGraphics = "org/lysis/reporters/html4r/elements/RAPHAELGraphics"
class.html4r.Title = "org/lysis/reporters/html4r/elements/Title"
class.pptx4r.DataTable = "org/lysis/reporters/pptx4r/elements/DataTable"
class.pptx4r.DMLGraphics = "org/lysis/reporters/pptx4r/elements/DMLGraphics"
class.pptx4r.SlideLayout = "org/lysis/reporters/pptx4r/elements/layouts/SlideLayout"
class.pptx4r.Paragraphs = "org/lysis/reporters/pptx4r/elements/Paragraphs"
class.docx4r.TableLayoutDOCX = "org/lysis/reporters/tables/TableLayoutDOCX"
class.html4r.TableLayoutHTML = "org/lysis/reporters/tables/TableLayoutHTML"
class.pptx4r.TableLayoutPPTX = "org/lysis/reporters/tables/TableLayoutPPTX"
class.docx4r.document = "org/lysis/reporters/docs/docx4R"
class.html4r.document = "org/lysis/reporters/docs/html4R"
class.html4r.HTMLPageContent = "org/lysis/reporters/docs/HTMLPageContent"
class.pptx4r.document = "org/lysis/reporters/docs/pptx4R"
class.pptx4r.SlideContent = "org/lysis/reporters/docs/SlideContent"
class.docx4j.WordprocessingMLPackage = "org/docx4j/openpackaging/packages/WordprocessingMLPackage"
class.FlexTable = "org/lysis/reporters/tables/FlexTable"
class.FlexRow = "org/lysis/reporters/tables/FlexRow"
class.FlexCell = "org/lysis/reporters/tables/FlexCell"
class.tables.BorderProperties = "org/lysis/reporters/tables/BorderProperties"
class.tables.CellProperties = "org/lysis/reporters/tables/CellProperties"
class.texts.ParProperties = "org/lysis/reporters/texts/ParProperties"
class.texts.TextProperties = "org/lysis/reporters/texts/TextProperties"
